@@ -585,7 +585,7 @@ class diagAide(QWidget):
 <p>"+self.tr("Clique long (1s) pour centrer la carte la position GPS.")+"</p> \
 <p></p> \
 <p><br /><b>"+self.tr("Panneaux:")+"</b></p> \
-<p><img src='img_panneaux.png'/> : "+self.tr("Clique pour cacher et d\xe9s\xe9lectionner la station.")+"</p> \
+<p><img src='/opt/rtap/img_panneaux.png'/> : "+self.tr("Clique pour cacher et d\xe9s\xe9lectionner la station.")+"</p> \
 <p></p> \
 <p><img src='/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing_pending.png' width='32' height='32'/> : "+self.tr("Calculer l'itin\xe9raire.")+"</p> \
 <p><img src='/usr/share/icons/hicolor/48x48/hildon/statusarea_sharing.png' width='32' height='32'/> : "+self.tr("Calcul en cours.")+"</p> \
